import { Type, Schema } from '@journeyapps/parser-schema';
import { SourceNode } from '@journeyapps/source-utils';
/**
 * Given a Journey type, return a TypeScript type name.
 *
 * If the type is unknown, we return 'any'.
 */
export declare function mapType(type: Type | null): string;
export interface SchemaDefinitionsOptions {
    dbs: string[];
    mobileUserType?: string;
    asynchronous?: boolean;
    sourcePath?: string;
}
export declare function schemaToDefinitions(schema: Schema, options: SchemaDefinitionsOptions): SourceNode;
/**
 * Get a reference to a model type/interface.
 *
 * "user" => "DB.user".
 * "class" => DB._class".
 *
 * @param modelName Name of the model.
 */
export declare function typeRef(modelName: string): string;
/**
 * Given a model name, return a safe identifier for the model interface.
 *
 * Generally the interface name should equal the model name. However, in some cases the model name is a reserved
 * keyword, in which case we prepend an underscore.
 *
 * "user" => "user"
 * "class" => "_class".
 *
 * @param name Name of the model.
 */
export declare function modelInterfaceName(name: string): string;
/**
 * Returns true if an identifier is valid as a property name in JavaScript / TypeScript.
 * In other words, it can be directly used as obj.prop_name_here, versus the workaround of obj["prop name here"].
 *
 * General restrictions are that it cannot start with a number, and cannot contain spaces or special characters.
 * @param name - The identifier
 */
export declare function isValidProperty(name: string): boolean;
/**
 * Return a property name safe to embed in a TS definition file.
 *
 * Where feasible, we return the property directly. If it's not a valid name directly, we wrap it in quotes.
 *
 * my_prop123 => my_prop123
 * 1time => "1time"
 * multiple words => "multiple words"
 *
 * @param name - The property name.
 */
export declare function safeProperty(name: string): string;
