"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SourceVFS = void 0;
const source_utils_1 = require("@journeyapps/source-utils");
/**
 * Serve source files directly.
 *
 * Wrap the fs with PrefixedFileSystem to serve under a prefix.
 */
class SourceVFS {
    /**
     *
     * @param fs - the source FileSystem
     * @param scriptDir - list files in this dir as scripts
     * @param scriptFilter - filter for scripts
     */
    constructor(fs, scriptDir, scriptFilter) {
        this.fs = fs;
        this.scriptDir = scriptDir;
        this.scriptFilter = scriptFilter;
    }
    getTargetsFor(source) {
        return null;
    }
    info(path) {
        if (this.fs.existsSync(path)) {
            const version = this.fs.getVersion(path);
            if (version == null) {
                return null;
            }
            return {
                path: path,
                generated: false,
                isScript: true,
                isModule: true,
                version: version
            };
        }
        else {
            return null;
        }
    }
    listFiles() {
        return this.fs.listFilesRecursivelySync(this.scriptDir, this.scriptFilter).sort();
    }
    read(path) {
        if (this.fs.existsSync(path)) {
            return source_utils_1.SourceNode.createDirectNode({ content: this.fs.readTextSync(path), sourceFile: path });
        }
        else {
            return null;
        }
    }
}
exports.SourceVFS = SourceVFS;
//# sourceMappingURL=SourceVFS.js.map