"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StaticVFS = void 0;
const source_utils_1 = require("@journeyapps/source-utils");
/**
 * Serves static files - typically generated, but could also be used for bundled files.
 */
class StaticVFS {
    constructor(entries) {
        this.entries = {};
        this.nodes = {};
        if (entries) {
            this.add(...entries);
        }
    }
    add(...entries) {
        for (let entry of entries) {
            this.entries[entry.path] = {
                path: entry.path,
                isModule: entry.isModule,
                isScript: entry.isScript,
                generated: entry.generated,
                version: '1'
            };
            this.nodes[entry.path] = source_utils_1.SourceNode.createDirectNode({ content: entry.content, sourceFile: entry.path });
        }
    }
    getTargetsFor(source) {
        // Even if the file is generated, it does not have sources.
        return null;
    }
    info(path) {
        var _a;
        return (_a = this.entries[path]) !== null && _a !== void 0 ? _a : null;
    }
    listFiles() {
        return Object.keys(this.entries);
    }
    read(path) {
        var _a;
        return (_a = this.nodes[path]) !== null && _a !== void 0 ? _a : null;
    }
}
exports.StaticVFS = StaticVFS;
//# sourceMappingURL=StaticVFS.js.map