import { StaticEntry } from './StaticVFS';
import { ExtraLibs } from './TypeScriptConfig';

/**
 * Default location for "extraLibs".
 */
export const DEFAULT_EXTRA_LIBS_LOCATION = 'file:///node_modules/';

/**
 * Default location for global imports file.
 */
export const DEFAULT_GLOBAL_IMPORTS = 'file:///gen/globals.d.ts';

/**
 * Default location for TypeScript built-in libs.
 */
export const DEFAULT_LIB_LOCATION = `${DEFAULT_EXTRA_LIBS_LOCATION}typescript/lib/`;

/**
 * Serve a hash of "extraLibs".
 */
export function extraLibsStatic(options: { extraLibs: ExtraLibs; prefix?: string }): StaticEntry[] {
  const prefix = options.prefix ?? DEFAULT_EXTRA_LIBS_LOCATION;
  let entries: StaticEntry[] = [];
  const defs = options.extraLibs;
  for (let key in defs) {
    const uri = `${prefix}${key}`;
    const def = defs[key];

    // For now, we only include the packages themselves.
    // We don't want the developer to import individual files.
    const fileName = key.split('/').pop();
    const isModule = fileName == 'package.json';

    entries.push({
      path: uri,
      content: def,
      generated: false,
      isScript: false,
      isModule
    });
  }
  return entries;
}

export interface ImportGlobalsOptions {
  preloadLibs: string[];

  definitionPath?: string;
}

export function importGlobalsStatic(options: ImportGlobalsOptions): StaticEntry {
  const path = options.definitionPath ?? DEFAULT_GLOBAL_IMPORTS;
  const content = options.preloadLibs.map((lib) => `import ${JSON.stringify(lib)};\n`).join('');
  const entry: StaticEntry = {
    path,
    content,
    generated: true,
    isScript: true,
    isModule: false
  };
  return entry;
}
